from datetime import datetime
from sqlalchemy import Boolean, Column, DateTime, Float, ForeignKey, Integer, String, Table, text
from sqlalchemy.orm import relationship
#from api.db.database import Base
from api.v1.models.base_model import BaseTableModel


class TaskUserAssociation(BaseTableModel):
    __tablename__ = 'task_user_association'

    task_id = Column(ForeignKey('tasks.id'), nullable=False)
    user_id = Column(ForeignKey('users.id'), nullable=False)

    submissions = relationship("TaskSubmission", back_populates="task_user", cascade="all, delete-orphan")
    task = relationship("Task", back_populates="assigned_users")
    user = relationship("User", back_populates="user_tasks")
    is_rewarded = Column(Boolean, nullable=False, server_default=text("false"))



class TaskSubmission(BaseTableModel):
    __tablename__ = 'task_submissions'

    task_user_id = Column(ForeignKey('task_user_association.id'), nullable=False)  # Link to task-user association
    link = Column(String, nullable=False) 
    is_verified = Column(Boolean, default=False, nullable=False)
    submitted_at = Column(DateTime, default=datetime.utcnow, nullable=False)
    verified_at = Column(DateTime, default=None, nullable=True)
    reward = Column(Float, nullable=False, server_default=text("0.0"))
    is_paid = Column(Boolean, nullable=False, server_default=text("false"))

    task_user = relationship("TaskUserAssociation", back_populates="submissions")
